#
# spec file for package python-pyhibp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pyhibp
Version:        4.2.0
Release:        2.1
Summary:        An interface to Troy Hunt's 'Have I Been Pwned' public API
License:        AGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://gitlab.com/kitsunix/pyHIBP/pyHIBP
Source:         https://files.pythonhosted.org/packages/source/p/pyhibp/pyhibp-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests >= 2.20.0 }
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.20.0
BuildArch:      noarch
%python_subpackages

%description
A Python interface to Troy Hunt's 'Have I Been Pwned?' (HIBP) public API.

%prep
%setup -q -n pyhibp-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

### Tests need network access to https://haveibeenpwned.com
#%%check
#%%pytest

%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.md
%{python_sitelib}/pyhibp
%{python_sitelib}/pyhibp-%{version}*-info

%changelog
* Wed Jun  4 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Wed Oct  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- v4.2.0 (2021-03-28)
  Adds a timeout value as a keyword argument to functions which hit the HIBP backend, so as to terminate connections
  if they exceed a defined duration (the same as requests.get(url=TARGET, timeout=VALUE) would function). The default value
  is set to 5.0. With thanks to Oskar Rosen for the
  suggestion!
* Mon Apr  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.0
  * Adds the capability to request that the Pwned Passwords API
    return padding to the responses to calls made via
    pwnedpasswords. Set the parameter add_padding to True on
    suffix_search or is_password_breached. See the HIBP API for
    additional information.
* Tue Aug 27 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.0.0
  * Breaking API change: The HIBP API now requires an API key for
    calls which search by account.
  * A User Agent must now be manually set.
  * Python 2.7 Support Dropped
  * Function modified: suffix_search(hash_prefix=prefix) is now the
    method to search for hash suffixes.
  * Read upstream changelog for more info.
* Mon Jul  1 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 3.1.0
  * New function: pwnedpasswords.suffix_search(hash_prefix=prefix)
    was created in order to have a dedicated function return the
    suffix list.
  * Function modification notice: pwnedpasswords.is_password_breached
    will be modified in an upcoming release to remove the ability
    to search for suffixes; use suffix_search(hash_prefix=prefix)
    instead. The parameter first_5_hash_chars will be removed as a
    consequence.
  * Upcoming return type change for empty sets: For the functions
    get_account_breaches, get_all_breaches, get_single_breach, and
    get_pastes--all contained in the pyhibp module--when no items
    would be returned from the HIBP backend, the returned item will
    be an empty object matching the standard return type for the
    function, and not a Boolean False.
    This will occur when v4.0.0 is released. Return types will be:
  - get_account_breaches -> [] / list
  - get_all_breaches -> [] / list
  - get_single_breach -> {} / dict
  - get_pastes -> [] / list
* Mon Jan 28 2019 mardnh@gmx.de
- Initial package, version 3.0.0
